pytest_xdist: pytest xdist plugin for distributed testing and loop-on-failing modes
===================================================================================

Description
-----------

pytest xdist plugin for distributed testing and loop-on-failing modes

License
-------

MIT

Upstream Contact
----------------

https://pypi.org/project/pytest-xdist/

